function [C,U,W]=BKSymFirst(A,r,u1,p,stage)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Distributed under a 3-Clause BSD License 
%
% Copyright 2021 Lars Eldén, Linköping University, and Maryam Dehghan,
% Federal University of Ceará,
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Start the BK expansion from u1
U(:,1) = u1/norm(u1); 
udim=1; ulast=U(:,1);

w1= double(ttv(A,{U(:,1),U(:,1)},[1,2]));
W(:,1) = w1/norm(w1);
wdim=1; wlast=W(:,1);

% First generate r=[r(1) r(1) r(3)] starting vectors from u1
% Symmetric minimal Krylov until size(U,2)= r(1)  and size(W,2)=r(3)
while udim < r(1) | wdim < r(3)
    if udim < r(1)
        u = double(ttv(A,{ulast,wlast},[2,3]));
        [U] = orthonorm(u,U);
        udim=udim+1; ulast=U(:,udim);
    end
    if wdim < r(3)
        w = double(ttv(A,{ulast,ulast},[1,2]));
        [W] = orthonorm(w,W);
        wdim=wdim+1; wlast=W(:,wdim);
    end
end
% Run one step of BKSym   to make a full expansion step
[C,U,W]=BKSym(A,U,W,p,stage);
    
end

function [U] = orthonorm(u,U)
% Orthonormalize u against U
h = U'*u;
v = u - U*h;
w = U'*v;
h = h + w;
v = v - U*w;
U = [U v/norm(v)];
end
