function [P1]=scaleMatrixSym(P)
% P is a symmetric adjacency matrix
% Scale P1=D^(-1/2)*P*D^(-1/2), where D=diag(d), and d=P*e.
% Also remove self-loops

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Distributed under a 3-Clause BSD License 
%
% Copyright 2021 Lars Eldén, Linköping University, and Maryam Dehghan,
% Federal University of Ceará,
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


m=size(P,1);
for i=1:m, P(i,i)=0; end

d=P*ones(m,1);
w=1./sqrt(d);
ii=find(w==inf);
w(ii)=0;
W=spdiags(w,0,m,m);
P1=W*P*W;               % Every slice is weighted to have Frobenius norm 1.
end
